import { IEntity, IEntityWrapper, IQueryWrapper, IDisabledWrapper, IKeyValue, IActionsDisabledWrapper } from '../../definitions.interface';
import { IExtendedEntity, ITabPanelWrapperEntity, ITabPanelEntity } from '../../definition';
import { IOptionEntity, IEditableEntity, IListWrapperEntity, IListEntity, ITransportWrapperEntity, IUserWrapperEntity, IDictionariesWrapperEntity, IUniversalApplicationStoreEntity, IPagedEntity, IDataMutatorEntity, IFilterFormWrapperEntity, IFormWrapperEntity, IDictionaryEntity, ISelectOptionEntity, IEditableEntityFormWrapperEntity, IQueryFilterWrapperEntity } from '../../entities-definitions.interface';
import { IFilterConfiguration, IFilterAndSorterConfiguration } from '../../configurations-definitions.interface';
export declare const dictionariesMapper: (storeEntity: IUniversalApplicationStoreEntity<{}>) => IDictionariesWrapperEntity;
export declare const userMapper: (storeEntity: IUniversalApplicationStoreEntity<{}>) => IUserWrapperEntity;
export declare const transportMapper: (storeEntity: IUniversalApplicationStoreEntity<{}>) => ITransportWrapperEntity;
/**
 * @stable [29.05.2018]
 * @param {IEditableEntity} editableEntity
 * @returns {IFilterFormWrapperEntity}
 */
export declare const filterFormMapper: (editableEntity: IEditableEntity<IKeyValue>) => IFilterFormWrapperEntity;
/**
 * @stable [14.06.2018]
 * @param {IEditableEntity} editableEntity
 * @returns {IEditableEntityFormWrapperEntity}
 */
export declare const formMapper: (editableEntity: IEditableEntity<IKeyValue>) => IEditableEntityFormWrapperEntity;
/**
 * @stable [16.05.2018]
 * @param {IListEntity} listEntity
 * @param {IDataMutatorEntity} dataMutator
 * @returns {IListWrapperEntity}
 */
export declare const listMapper: (listEntity: IListEntity, dataMutator?: IDataMutatorEntity<IEntity>) => IListWrapperEntity;
/**
 * @stable [09.05.2018]
 * @param {IListEntity} listEntity
 * @param {number} pageSize
 * @returns {IPagedEntity}
 */
export declare const listEntityPageEntityFilterMapper: (listEntity: IListEntity, pageSize?: number) => IPagedEntity;
/**
 * @stable [09.05.2018]
 * @param {IListWrapperEntity} listEntity
 * @param {number} pageSize
 * @returns {IPagedEntity}
 */
export declare const listEntityWrapperPageEntityFilterMapper: (listEntity: IListWrapperEntity, pageSize?: number) => IPagedEntity;
/**
 * @stable [30.01.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IListEntity}
 */
export declare const listSelector: (listWrapperEntity: IListWrapperEntity) => IListEntity;
/**
 * @stable [16.05.2018]
 * @param {IListWrapperEntity} listWrapperEntity
 * @param {IDataMutatorEntity} dataMutator
 * @returns {IListWrapperEntity}
 */
export declare const listWrapperMapper: (listWrapperEntity: IListWrapperEntity, dataMutator?: IDataMutatorEntity<IEntity>) => IListWrapperEntity;
/**
 * @stable [31.08.2018]
 * @param {ITabPanelEntity} tabPanel
 * @returns {ITabPanelEntity}
 */
export declare const tabPanelMapper: (tabPanel: ITabPanelEntity) => ITabPanelWrapperEntity;
/**
 * @stable [30.08.2018]
 * @param {ITabPanelWrapperEntity} tabPanelWrapperEntity
 * @returns {ITabPanelWrapperEntity}
 */
export declare const tabPanelWrapperMapper: (tabPanelWrapperEntity: ITabPanelWrapperEntity) => ITabPanelWrapperEntity;
/**
 * @stable [05.08.2018]
 * @param {IFilterFormWrapperEntity} filterFormWrapperEntity
 * @param {boolean} useFormMapper
 * @returns {TResult}
 */
export declare const filterFormWrapperMapper: <TResult = IFilterFormWrapperEntity | IFormWrapperEntity<IEntity>>(filterFormWrapperEntity: IFilterFormWrapperEntity, useFormMapper?: boolean) => TResult;
/**
 * @stable [05.08.2018]
 * @param {IFilterFormWrapperEntity} filterFormWrapperEntity
 * @returns {TResult}
 */
export declare const filterFormChangesWrapperMapper: <TResult = IEntity>(filterFormWrapperEntity: IFilterFormWrapperEntity) => TResult;
/**
 * @stable [17.01.2019]
 * @param {IEditableEntity} entity
 * @returns {TResult}
 */
export declare const editableEntityChangesSelector: <TResult extends IEntity = IEntity>(entity: IEditableEntity<IKeyValue>) => TResult;
/**
 * @stable [17.01.2019]
 * @param {IEditableEntity} editableEntity
 * @returns {TResult}
 */
export declare const editableEntityChangesMapper: <TResult extends IEntity = IEntity>(editableEntity: IEditableEntity<IKeyValue>) => TResult;
/**
 * @stable [05.08.2018]
 * @param {IQueryFilterWrapperEntity} queryFilterWrapperEntity
 * @returns {IQueryWrapper}
 */
export declare const filterQueryWrapperMapper: (queryFilterWrapperEntity: IQueryFilterWrapperEntity) => IQueryWrapper<string>;
/**
 * @stable [19.12.2018]
 * @param {IListWrapperEntity} entity
 * @returns {IFilterConfiguration}
 */
export declare const refreshedListWrapperEntityMapper: (entity: IListWrapperEntity) => IFilterConfiguration;
export declare const entityMapper: <TEntity extends IEntity>(entity: TEntity, formEntity?: IEditableEntity<IKeyValue>) => IExtendedEntity<TEntity>;
/**
 * @stable [09.05.2018]
 * @param {IListEntity} listEntity
 * @returns {TEntity}
 */
export declare const selectedEntitySelector: <TEntity extends IEntity>(listEntity: IListEntity) => TEntity;
/**
 * @stable [10.01.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {TEntity}
 */
export declare const listSelectedEntitySelector: <TEntity extends IEntity>(listWrapperEntity: IListWrapperEntity) => TEntity;
export declare const listWrapperSelectedEntityMapper: <TEntity extends IEntity>(listWrapperState: IListWrapperEntity, formEntity?: IEditableEntity<IKeyValue>) => IEntityWrapper<TEntity>;
/**
 * @stable [19.12.2018]
 * @param {IListEntity} listEntity
 * @returns {IDisabledWrapper}
 */
export declare const disabledListEntityMapper: (listEntity: IListEntity) => IDisabledWrapper;
/**
 * @stable [29.05.2018]
 * @param {IListEntity} listEntity
 * @returns {IActionsDisabledWrapper}
 */
export declare const actionsDisabledListEntityMapper: (listEntity: IListEntity) => IActionsDisabledWrapper;
/**
 * @stable [29.05.2018]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IActionsDisabledWrapper}
 */
export declare const actionsDisabledListWrapperEntityMapper: (listWrapperEntity: IListWrapperEntity) => IActionsDisabledWrapper;
/**
 * @stable [19.12.2018]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IDisabledWrapper}
 */
export declare const disabledListWrapperEntityMapper: (listWrapperEntity: IListWrapperEntity) => IDisabledWrapper;
/**
 * @stable [31.08.2018]
 * @param {TEntity[] | TEntity} data
 * @param {IFilterAndSorterConfiguration} config
 * @returns {Array<ISelectOptionEntity<TEntity extends IOptionEntity>>}
 */
export declare const selectOptionsMapper: <TEntity extends IOptionEntity>(data: TEntity | TEntity[], config?: IFilterAndSorterConfiguration) => ISelectOptionEntity<TEntity>[];
/**
 * @stable [16.06.2018]
 * @param {IDictionaryEntity<TDictionaryEntity>} dictionaryEntity
 * @param {IFilterAndSorterConfiguration} config
 * @returns {Array<ISelectOptionEntity<TDictionaryEntity>>}
 */
export declare const dictionaryEntityMapper: <TDictionaryEntity>(dictionaryEntity: IDictionaryEntity<TDictionaryEntity>, config?: IFilterAndSorterConfiguration) => ISelectOptionEntity<TDictionaryEntity>[];
/**
 * @stable [20.12.2018]
 * @param {IDictionaryEntity<TDictionaryEntity>} dictionaryEntity
 * @param {(data: (TDictionaryEntity[] | TDictionaryEntity)) => TResult} accessor
 * @returns {TResult}
 */
export declare const dictionaryEntityDataMapper: <TDictionaryEntity, TResult = TDictionaryEntity | TDictionaryEntity[]>(dictionaryEntity: IDictionaryEntity<TDictionaryEntity>, accessor?: (data: TDictionaryEntity | TDictionaryEntity[]) => TResult) => TResult;
/**
 * @stable [29.05.2018]
 */
export declare const universalDefaultMappers: (((storeEntity: IUniversalApplicationStoreEntity<{}>) => IDictionariesWrapperEntity) | ((storeEntity: IUniversalApplicationStoreEntity<{}>) => IUserWrapperEntity) | ((storeEntity: IUniversalApplicationStoreEntity<{}>) => ITransportWrapperEntity))[];
