import { IEntity, AnyT } from '../../../definitions.interface';
import { IMultiItemEntity, MultiItemEntityT, IMultiItemFileEntity } from '../../../entities-definitions.interface';
import { VueField } from '../field/vue-index';
import { MultiFieldPlugin } from '../multifield/vue-index';
import { IVueBaseFileViewerProps, IVueViewerListenersEntity } from '../../viewer/vue-index';
import { IVueBaseFileFieldProps, IVueBaseFileFieldTemplateMethods } from './vue-filefield.interface';
export declare class VueBaseFileField extends VueField implements IVueBaseFileFieldTemplateMethods, IVueBaseFileFieldProps {
    readonly displayFileName: string;
    readonly displayFileFormat: string;
    readonly placeholderFactory: (index: number) => string;
    readonly canRenderAttachment: (entity: IMultiItemEntity, index: number) => boolean;
    readonly maxFiles: number;
    readonly openViewerPopupOnFileSelect: boolean;
    readonly defaultDndMessage: string;
    readonly defaultDndMessageFactory: (index: number) => string;
    readonly viewer: string;
    readonly type: string;
    protected readonly viewerProps: IVueBaseFileViewerProps;
    protected readonly multiFieldPlugin: MultiFieldPlugin;
    protected readonly cachedFiles: Map<string, File>;
    /**
     * @stable [27.11.2018]
     */
    constructor();
    /**
     * @stable [25.11.2018]
     * @returns {string}
     */
    getFieldClassName(): string;
    /**
     * @stable [11.02.2019]
     * @param {File[]} files
     * @param {IMultiItemFileEntity | IEntity} replacedEntity
     * @param {number} index
     */
    onFilesSelect(files: File[], replacedEntity: IMultiItemFileEntity | IEntity, index: number): void;
    /**
     * @stable [12.02.2019]
     * @param {IMultiItemFileEntity | IEntity} entity
     * @param {number} index
     * @returns {string}
     */
    getDefaultDndMessage(entity: IMultiItemFileEntity | IEntity, index: number): string;
    /**
     * @stable [12.02.2019]
     * @param {IMultiItemFileEntity | IEntity} entity
     * @param {number} index
     * @returns {string}
     */
    getCustomDndMessage(entity: IMultiItemFileEntity | IEntity, index: number): string;
    /**
     * [<Placeholder: optional> + <Default DnD message>]
     *
     * @stable [22.12.2018]
     * @param {MultiItemEntityT} entityOrEntityId
     * @param {number} index
     * @returns {string}
     */
    getPlaceholder(entityOrEntityId: MultiItemEntityT, index: number): string;
    /**
     * @stable [20.12.2018]
     * @returns {IEntity[]}
     */
    getEntities(): IEntity[];
    /**
     * @stable [11.02.2019]
     * @param {IMultiItemFileEntity | IEntity} entity
     * @param {number} index
     * @returns {boolean}
     */
    canRenderAttachmentContent(entity: IMultiItemFileEntity | IEntity, index: number): boolean;
    /**
     * @stable [22.12.2018]
     * @param {MultiItemEntityT} entityOrEntityId
     * @param {number} index
     * @returns {IVueBaseFileViewerProps}
     */
    getViewerBindings(entityOrEntityId: MultiItemEntityT, index: number): IVueBaseFileViewerProps;
    /**
     * @stable [16.12.2018]
     * @param {MultiItemEntityT} entityOrEntityId
     * @param {number} index
     * @returns {IVueViewerListenersEntity<File>}
     */
    getViewerListeners(entityOrEntityId: IMultiItemEntity, index: number): IVueViewerListenersEntity<File>;
    /**
     * @stable [21.12.2018]
     * @param {File} file
     * @param {number} index
     * @returns {string}
     */
    getViewerComponent(file: File, index: number): string;
    /**
     * @stable [11.02.2019]
     * @param {MultiItemEntityT} entityOrEntityId
     * @param {number} index
     * @returns {string}
     */
    getAttachmentContentClassName(entityOrEntityId: MultiItemEntityT, index: number): string;
    /**
     * @stable [17.11.2018]
     * @returns {string}
     */
    protected getInputClassName(): string;
    /**
     * @stable [09.12.2018]
     * @returns {string}
     */
    protected getFieldAttachmentTemplate(): string;
    /**
     * @stable [10.12.2018]
     * @returns {TMethods}
     */
    protected getTemplateMethods<TMethods extends IVueBaseFileFieldTemplateMethods>(): TMethods;
    protected getFileFormat(): AnyT;
    /**
     * @stable [19.01.2019]
     * @param {string} type
     * @returns {string}
     */
    protected toViewer(type: string): string;
    /**
     * @stable [10.12.2018]
     * @param {File} file
     * @returns {string}
     */
    private toFileUrl;
    /**
     * @stable [28.11.2018]
     * @param {string} fileUrl
     */
    private destroyFileUrl;
    /**
     * @stable [27.02.2019]
     * @param {IMultiItemFileEntity | IEntity} entity
     * @param {File} file
     * @param {number} index
     */
    private onFileChange;
    private getFileName;
    /**
     * @stable [11.02.2019]
     * @param {MultiItemEntityT} entityOrEntityId
     * @param {number} index
     * @returns {string}
     */
    private toAttachmentContentClassName;
    /**
     * @stable [27.02.2019]
     * @param {IMultiItemFileEntity} entity
     * @param {File} file
     * @param {string} fileUrl
     * @param {number} index
     */
    private replaceFile;
    /**
     * @stable [27.02.2019]
     * @param {File} file
     * @param {string} fileUrl
     * @param {number} index
     */
    private addFile;
    /**
     * @stable [27.02.2019]
     * @param {IMultiItemFileEntity} entity
     * @param {File} file
     * @param {string} fileUrl
     * @param {number} index
     */
    private editFile;
    /**
     * @stable [11.02.2019]
     * @param {IMultiItemFileEntity | IEntity | EntityIdT} entity
     */
    private removeFile;
    /**
     * @stable [27.02.2019]
     */
    private openViewerPopup;
}
