"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var multifield_support_1 = require("./multifield.support");
var definitions_interface_1 = require("../../../definitions.interface");
describe('multifield.support', function () {
    describe('toActualMultiItemEntities2', function () {
        var itemsCount = 6;
        it('test1', function () {
            var item1 = { id: 100, name: 'name1' };
            var item2 = { id: 101, name: 'name2' };
            var item3 = { id: 103, name: 'name3', newEntity: true, index: 4 };
            var result = multifield_support_1.asViewedMultiItemEntities([item3, item1, item2], itemsCount);
            expect(result).toEqual([item1, item2, definitions_interface_1.UNDEF, definitions_interface_1.UNDEF, item3, definitions_interface_1.UNDEF]);
        });
        it('test2', function () {
            var item1 = { id: 100, name: 'name1' };
            var item2 = { id: 101, name: 'name2' };
            var item3 = { id: 103, name: 'name3', newEntity: true, index: 4 };
            var result = multifield_support_1.asViewedMultiItemEntities([item1, item2, item3], itemsCount);
            expect(result).toEqual([item1, item2, definitions_interface_1.UNDEF, definitions_interface_1.UNDEF, item3, definitions_interface_1.UNDEF]);
        });
        it('test3', function () {
            var item1 = { id: 100, name: 'name1' };
            var item2 = { id: 101, name: 'name2', index: 1 };
            var result = multifield_support_1.asViewedMultiItemEntities([item1, item2], itemsCount);
            expect(result).toEqual([item1, item2, definitions_interface_1.UNDEF, definitions_interface_1.UNDEF, definitions_interface_1.UNDEF, definitions_interface_1.UNDEF]);
        });
    });
    describe('toMultiFieldChangesEntityOnDelete', function () {
        it('test1', function () {
            var item1 = { id: 100, field1: 20, field2: 30 };
            var item2 = { id: 101, field1: 200, field2: 300 };
            var item3 = { id: 102, field1: 2000, field2: 3000 };
            var result = multifield_support_1.toMultiFieldChangesEntityOnDelete({ id: 100 }, // payload
            [item1, item2], // add
            [], // remove
            [{ id: 102, name: 'field2', value: 3001, rawData: item3 }], // edit
            [] // original
            );
            expect(result).toEqual({
                removeArray: [],
                editArray: [{ id: 102, name: 'field2', value: 3001, rawData: item3 }],
                addArray: [item2],
            });
        });
        it('test2', function () {
            var item1 = { id: 100, field1: 20, field2: 30 };
            var item2 = { id: 101, field1: 200, field2: 300 };
            var item3 = { id: 102, field1: 2000, field2: 3000 };
            var result = multifield_support_1.toMultiFieldChangesEntityOnDelete({ id: 102 }, // payload
            [item1, item2], // add
            [], // remove
            [{ id: 102, name: 'field2', value: 3001, rawData: item3 }], // edit
            [] // original
            );
            expect(result).toEqual({
                removeArray: [],
                editArray: [],
                addArray: [item1, item2],
            });
        });
        it('test3', function () {
            var item1 = { id: 100, field1: 20, field2: 30 };
            var item2 = { id: 101, field1: 200, field2: 300 };
            var item3 = { id: 102, field1: 2000, field2: 3000 };
            var item4 = { id: 103, field1: 20000, field2: 30000 };
            var result = multifield_support_1.toMultiFieldChangesEntityOnDelete({ id: 103 }, // payload
            [item1, item2], // add
            [], // remove
            [{ id: 102, name: 'field2', value: 3001, rawData: item3 }], // edit
            [item3, item4] // original
            );
            expect(result).toEqual({
                removeArray: [item4],
                editArray: [{ id: 102, name: 'field2', value: 3001, rawData: item3 }],
                addArray: [item1, item2],
            });
        });
        it('test4', function () {
            var item1 = { id: 100, field1: 20, field2: 30 };
            var item2 = { id: 101, field1: 200, field2: 300 };
            var item3 = { id: 102, field1: 2000, field2: 3000 };
            var item4 = { id: 103, field1: 20000, field2: 30000 };
            var item5 = { id: 104, field1: 200000, field2: 300000 };
            var result = multifield_support_1.toMultiFieldChangesEntityOnDelete({ id: 103 }, // payload
            [item1, item2], // add
            [item5], // remove
            [{ id: 102, name: 'field2', value: 3001, rawData: item3 }], // edit
            [item3, item4, item5] // original
            );
            expect(result).toEqual({
                removeArray: [item4, item5],
                editArray: [{ id: 102, name: 'field2', value: 3001, rawData: item3 }],
                addArray: [item1, item2],
            });
        });
    });
    describe('toMultiFieldChangesEntityOnEdit', function () {
        it('test1', function () {
            var item1 = { id: 100, field1: 20, field2: 30 };
            var item2 = { id: 101, field1: 200, field2: 300 };
            var result = multifield_support_1.toMultiFieldChangesEntityOnEdit({ name: 'field1', value: 21, id: 100, rawData: item1 }, // payload
            [item1, item2], // add
            [], // remove
            [{ id: 101, name: 'field2', value: 301, rawData: item2 }], // edit
            [] // original
            );
            expect(result).toEqual({
                removeArray: [],
                editArray: [{ id: 101, name: 'field2', value: 301, rawData: item2 }],
                addArray: [Object.assign({}, item1, { field1: 21 }), item2],
            });
        });
        it('test2', function () {
            var item1 = { id: 100, field1: 20, field2: 30 };
            var item2 = { id: 101, field1: 200, field2: 300 };
            var item3 = { id: 102, field1: 2000, field2: 3000 };
            var result = multifield_support_1.toMultiFieldChangesEntityOnEdit({ name: 'field1', value: 21, id: 100, rawData: item1 }, // payload
            [], // add
            [], // remove
            [], // edit
            [item1, item2, item3] // original
            );
            expect(result).toEqual({
                removeArray: [],
                editArray: [{ id: 100, name: 'field1', value: 21, rawData: item1 }],
                addArray: [],
            });
        });
        it('test3', function () {
            var item1 = { id: 100, field1: 20, field2: 30 };
            var item2 = { id: 101, field1: 200, field2: 300 };
            var item3 = { id: 102, field1: 2000, field2: 3000 };
            var result = multifield_support_1.toMultiFieldChangesEntityOnEdit({ id: 100, name: 'field1', value: 21, rawData: item1 }, // payload
            [], // add
            [], // remove
            [{ id: 101, name: 'field2', value: 301, rawData: item2 }], // edit
            [item1, item2, item3] // original
            );
            expect(result).toEqual({
                removeArray: [],
                editArray: [
                    { id: 101, name: 'field2', value: 301, rawData: item2 },
                    { id: 100, name: 'field1', value: 21, rawData: item1 }
                ],
                addArray: [],
            });
        });
        it('test4', function () {
            var item1 = { id: 100, field1: 20, field2: 30 };
            var item2 = { id: 101, field1: 200, field2: 300 };
            var item3 = { id: 102, field1: 2000, field2: 3000 };
            var result = multifield_support_1.toMultiFieldChangesEntityOnEdit({ id: 101, name: 'field2', value: 300, rawData: item1 }, // payload
            [], // add
            [], // remove
            [{ id: 101, name: 'field2', value: 301, rawData: item2 }], // edit
            [item1, item2, item3] // original
            );
            expect(result).toEqual({
                removeArray: [],
                editArray: [],
                addArray: [],
            });
        });
        it('test5', function () {
            var item1 = { id: 100, field1: 20, field2: 30 };
            var item2 = { id: 101, field1: 200, field2: 300 };
            var item3 = { id: 102, field1: 2000, field2: 3000 };
            var result = multifield_support_1.toMultiFieldChangesEntityOnEdit({ id: 101, name: 'field2', value: 300, rawData: item1 }, // payload
            [], // add
            [], // remove
            [
                { id: 101, name: 'field2', value: 301, rawData: item2 },
                { id: 101, name: 'field1', value: 201, rawData: item2 }
            ], // edit
            [item1, item2, item3] // original
            );
            expect(result).toEqual({
                removeArray: [],
                editArray: [{ id: 101, name: 'field1', value: 201, rawData: item2 }],
                addArray: [],
            });
        });
    });
    describe('buildMultiEditItemEntityPayload', function () {
        it('test1', function () {
            var entity = Object.freeze({ id: 1, count: 100 });
            var result = multifield_support_1.buildMultiEditItemEntityPayload('count', [entity], function (itm) { return itm.id === entity.id; }, function (itm) { return entity.count + 1; });
            expect(result).toEqual({ id: 1, value: 101, name: 'count', rawData: { id: 1, count: 100 } });
        });
        it('test2', function () {
            var entity = Object.freeze({ id: 1, count: 100 });
            var result = multifield_support_1.buildMultiEditItemEntityPayload('count', {
                add: [],
                remove: [],
                edit: [{ id: entity.id, name: 'count', value: 101, rawData: entity }],
                source: [entity],
            }, function (itm) { return itm.id === entity.id; }, function (itm) { return itm.value + 1; });
            expect(result).toEqual({ id: 1, value: 102, name: 'count', rawData: { id: 1, count: 100 } });
        });
    });
    describe('normalizeEntities', function () {
        it('test1', function () {
            var ids = multifield_support_1.normalizeEntities(1);
            expect(ids).toEqual([{ id: 1 }]);
        });
        it('test2', function () {
            var ids = multifield_support_1.normalizeEntities([{ id: 1 }]);
            expect(ids).toEqual([{ id: 1 }]);
        });
    });
    describe('toActualMultiItemEntitiesLength', function () {
        it('test1', function () {
            var length = multifield_support_1.toActualMultiItemEntitiesLength(1);
            expect(length).toEqual(1);
        });
        it('test2', function () {
            var length = multifield_support_1.toActualMultiItemEntitiesLength('1');
            expect(length).toEqual(1);
        });
        it('test3', function () {
            var length = multifield_support_1.toActualMultiItemEntitiesLength([{ id: 1 }, { id: 2 }]);
            expect(length).toEqual(2);
        });
        it('test4', function () {
            var length = multifield_support_1.toActualMultiItemEntitiesLength(definitions_interface_1.UNDEF);
            expect(length).toEqual(0);
        });
        it('test5', function () {
            var length = multifield_support_1.toActualMultiItemEntitiesLength({
                add: [{ id: 1 }],
                remove: [{ id: 2 }],
                edit: [],
                source: [{ id: 3 }],
            });
            expect(length).toEqual(2);
        });
        it('test6', function () {
            var length = multifield_support_1.toActualMultiItemEntitiesLength({
                add: [{ id: 1 }],
                remove: [{ id: 2 }],
                edit: [],
            });
            expect(length).toEqual(1);
        });
        it('test7', function () {
            var length = multifield_support_1.toActualMultiItemEntitiesLength({
                add: [{ id: 1 }, { id: 3 }],
                remove: [{ id: 2 }],
                edit: [],
            });
            expect(length).toEqual(2);
        });
        it('test8', function () {
            var length = multifield_support_1.toActualMultiItemEntitiesLength({
                add: [],
                remove: [{ id: 1 }],
                edit: [],
            });
            expect(length).toEqual(0);
        });
        it('test9', function () {
            var length = multifield_support_1.toActualMultiItemEntitiesLength({
                add: [],
                remove: [{ id: 1 }],
                edit: [],
                source: [{ id: 2 }],
            });
            expect(length).toEqual(1);
        });
        it('test10', function () {
            var length = multifield_support_1.toActualMultiItemEntitiesLength({
                add: [{ id: '1' }],
                remove: [{ id: '2' }],
                edit: [],
                source: [{ id: '3' }],
            });
            expect(length).toEqual(2);
        });
    });
    describe('fromMultiFieldEntityToEntitiesIds', function () {
        it('test1', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds({
                add: [],
                remove: [],
                edit: [],
                source: [],
            });
            expect(ids).toEqual([]);
        });
        it('test2', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds({
                add: [],
                remove: [],
                edit: [],
            });
            expect(ids).toEqual([]);
        });
        it('test3', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds({
                add: [{ id: 1 }],
                remove: [],
                edit: [],
                source: [],
            });
            expect(ids).toEqual([1]);
        });
        it('test4', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds({
                add: [{ id: 1 }, { id: 2 }],
                remove: [],
                edit: [],
                source: [],
            });
            expect(ids).toEqual([1, 2]);
        });
        it('test5', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds({
                add: [{ id: 1 }, { id: 2 }],
                remove: [],
                edit: [],
                source: [{ id: 3 }],
            });
            expect(ids).toEqual([1, 2, 3]);
        });
        it('test6', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds({
                add: [{ id: 1 }, { id: 2 }],
                remove: [{ id: 3 }],
                edit: [],
                source: [{ id: 3 }],
            });
            expect(ids).toEqual([1, 2]);
        });
        it('test7', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds({
                add: [],
                remove: [{ id: 3 }],
                edit: [],
                source: [{ id: 3 }],
            });
            expect(ids).toEqual([]);
        });
        it('test8', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds({
                add: [],
                remove: [{ id: 3 }],
                edit: [],
                source: [{ id: 3 }, { id: 4 }],
            });
            expect(ids).toEqual([4]);
        });
        it('test9', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds({
                add: [{ id: 1 }],
                remove: [],
                edit: [],
                source: [{ id: 2 }, { id: 3 }],
            });
            expect(ids).toEqual([1, 2, 3]);
        });
        it('test10', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds({
                add: [{ id: 1 }],
                remove: [],
                edit: [],
            });
            expect(ids).toEqual([1]);
        });
        it('test11', function () {
            var ids = multifield_support_1.fromMultiFieldEntityToEntitiesIds([{ id: 1 }, { id: 2 }]);
            expect(ids).toEqual([1, 2]);
        });
        it('test12', function () {
            expect(multifield_support_1.fromMultiFieldEntityToEntitiesIds(definitions_interface_1.UNDEF)).toEqual(definitions_interface_1.UNDEF);
        });
    });
    describe('toActualMultiItemEditedEntities', function () {
        it('test1', function () {
            var data = multifield_support_1.toActualMultiItemEditedEntities({
                add: [],
                remove: [],
                edit: [{ id: 1, name: 'field1', value: 101 }],
                source: [{ id: 1, field1: 100 }],
            });
            var result = [];
            result.push({ id: 1, field1: 101 });
            expect(data).toEqual(result);
        });
        it('test2', function () {
            var data = multifield_support_1.toActualMultiItemEditedEntities(definitions_interface_1.UNDEF);
            expect(data).toEqual(definitions_interface_1.UNDEF);
        });
        it('test3', function () {
            var data = multifield_support_1.toActualMultiItemEditedEntities(null);
            expect(data).toEqual(definitions_interface_1.UNDEF);
        });
        it('test4', function () {
            var data = multifield_support_1.toActualMultiItemEditedEntities({
                add: [],
                remove: [],
                edit: [{ id: 1, name: 'field1', value: 101 }, { id: 1, name: 'field2', value: 201 }],
                source: [{ id: 1, field1: 100, field2: 200 }, { id: 2, field3: 202 }],
            });
            var result = [];
            result.push({ id: 1, field1: 101, field2: 201 });
            expect(data).toEqual(result);
        });
    });
    describe('fromMultiFieldEntityToEntities', function () {
        it('test1', function () {
            var data = multifield_support_1.fromMultiFieldEntityToEntities([{ id: 100, name: 'name100' }, { id: 200, name: 'name200' }], function (entity, index) { return Object.assign({}, entity, { extraField: "extraField" + index }); });
            var result = [];
            result.push({ id: 100, name: 'name100', extraField: 'extraField0' });
            result.push({ id: 200, name: 'name200', extraField: 'extraField1' });
            expect(data).toEqual(result);
        });
        it('test2', function () {
            var data = multifield_support_1.fromMultiFieldEntityToEntities(null, function (entity, index) { return Object.assign({}, entity, { extraField: "extraField" + index }); });
            expect(data).toEqual(definitions_interface_1.UNDEF);
        });
        it('test3', function () {
            var data = multifield_support_1.fromMultiFieldEntityToEntities(definitions_interface_1.UNDEF, function (entity, index) { return Object.assign({}, entity, { extraField: "extraField" + index }); });
            expect(data).toEqual(definitions_interface_1.UNDEF);
        });
        it('test4', function () {
            var data = multifield_support_1.fromMultiFieldEntityToEntities({
                add: [{ id: 100, name: 'name100' }, { id: 200, name: 'name200' }],
                remove: [],
                edit: [],
            }, function (entity, index) { return Object.assign({}, entity, { extraField: "extraField" + index }); });
            var result = [];
            result.push({ id: 100, name: 'name100', extraField: 'extraField0' });
            result.push({ id: 200, name: 'name200', extraField: 'extraField1' });
            expect(data).toEqual(result);
        });
        it('test5', function () {
            var data = multifield_support_1.fromMultiFieldEntityToEntities({
                add: [{ id: 100, name: 'name100' }],
                remove: [{ id: 200, name: 'name200' }],
                edit: [],
                source: [{ id: 200, name: 'name200' }, { id: 200, name: 'name200' }],
            }, function (entity, index) { return Object.assign({}, entity, { extraField: "extraField" + index }); });
            var result = [];
            result.push({ id: 100, name: 'name100', extraField: 'extraField0' });
            expect(data).toEqual(result);
        });
        it('test5', function () {
            var data = multifield_support_1.fromMultiFieldEntityToEntities({
                add: [],
                remove: [],
                edit: [{ id: 100, value: 'name101', name: 'name', rawData: { id: 100, name: 'name100' } }],
                source: [{ id: 100, name: 'name100' }],
            }, function (entity, index) { return Object.assign({}, entity, { extraField: "extraField" + index }); });
            var result = [];
            result.push({ id: 100, name: 'name101', extraField: 'extraField0' });
            expect(data).toEqual(result);
        });
    });
});
//# sourceMappingURL=multifield.support.spec.js.map