"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var tabpanel_support_1 = require("../tabpanel/tabpanel.support");
/**
 * @stable [29.05.2018]
 * @param {IFormProps} formProps
 * @param {IFieldConfiguration} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldReadOnly = function (formProps, fieldProps) {
    return (R.isNil(fieldProps.readOnly) ? formProps.readOnly : fieldProps.readOnly) === true;
};
/**
 * @stable [29.05.2018]
 * @param {IFormProps} formProps
 * @param {IFieldConfiguration} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldDisabled = function (formProps, fieldProps) {
    return R.isNil(fieldProps.disabled)
        ? exports.isFormDisabled(formProps)
        : fieldProps.disabled === true;
};
/**
 * @stable [16.11.2018]
 * @param {IFormProps} formProps
 * @param {IFieldConfiguration} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldChangeable = function (formProps, fieldProps) {
    return R.isNil(fieldProps.changeable)
        ? exports.isFormChangeable(formProps)
        : fieldProps.changeable !== false;
};
/**
 * @stable [29.05.2018]
 * @param {IFormProps} formProps
 * @returns {boolean}
 */
exports.isFormDisabled = function (formProps) {
    return formProps.disabled === true || formProps.form.progress === true;
};
/**
 * @stable [16.11.2018]
 * @param {IFormProps} formProps
 * @returns {boolean}
 */
exports.isFormChangeable = function (formProps) { return formProps.changeable !== false; };
/**
 * @stable [03.08.2018]
 * @param {IFormProps} formProps
 * @returns {boolean}
 */
exports.isFormValid = function (formProps) {
    return R.isNil(formProps.form.valid) || formProps.form.valid === true;
};
/**
 * @stable [29.05.2018]
 * @param {IFormProps} formProps
 * @returns {boolean}
 */
exports.isFormEditable = function (formProps) {
    return R.isNil(formProps.editable) || formProps.editable === true;
};
/**
 * @stable [29.05.2018]
 * @param {IFormProps} formProps
 * @returns {boolean}
 */
exports.isFormDirty = function (formProps) {
    return formProps.alwaysDirty || formProps.form.dirty === true;
};
/**
 * @stable [03.08.2018]
 * @param {IFormProps} formProps
 * @returns {boolean}
 */
exports.isFormSubmittable = function (formProps) {
    return exports.isFormValid(formProps)
        && exports.isFormEditable(formProps)
        && exports.isFormDirty(formProps)
        && !exports.isFormDisabled(formProps);
};
/**
 * @stable [15.02.2019]
 * @param {IFormProps} formProps
 * @returns {boolean}
 */
exports.isFormResettable = function (formProps) { return formProps.alwaysResettable || exports.isFormSubmittable(formProps); };
/**
 * @stable [29.05.2018]
 * @param {IFormProps} formProps
 * @returns {boolean}
 */
exports.isFormOfNewEntity = function (formProps) { return R.isNil(formProps.entity) || R.isNil(formProps.entity.id); };
/**
 * @stable [25.02.2019]
 * @param {IFormProps} formProps
 * @returns {boolean}
 */
exports.isFormBusy = function (formProps) { return formProps.progress || formProps.form.progress; };
/**
 * @stable [30.08.2018]
 * @param {IFormProps} formProps
 * @param {ITabConfiguration} tab
 * @returns {boolean}
 */
exports.isFormTabActive = function (formProps, tab) {
    return tabpanel_support_1.isTabActive(formProps.form, tab);
};
/**
 * @stable [30.08.2018]
 * @param {IFormProps} formProps
 * @param {ITabPanelConfiguration} tabPanelConfiguration
 * @returns {number}
 */
exports.getFormTabActiveValue = function (formProps, tabPanelConfiguration) {
    return tabpanel_support_1.getTabActiveValue(formProps.form, tabPanelConfiguration);
};
//# sourceMappingURL=form.support.js.map