"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var util_1 = require("../../util");
var universal_component_1 = require("../base/universal.component");
var UniversalList = /** @class */ (function (_super) {
    __extends(UniversalList, _super);
    /**
     * @stable [23.04.2018]
     * @param {TProps} props
     */
    function UniversalList(props) {
        var _this = _super.call(this, props) || this;
        _this.onCreate = _this.onCreate.bind(_this);
        _this.onSelect = _this.onSelect.bind(_this);
        return _this;
    }
    /**
     * @stable [21.06.2018]
     * @returns {JSX.Element}
     */
    UniversalList.prototype.render = function () {
        var props = this.props;
        if (this.originalDataSourceDoesNotExist
            || this.emptyData
            || props.progress
            || props.error) {
            return this.getMessage();
        }
        return this.getView();
    };
    /**
     * @stable [23.04.2018]
     */
    UniversalList.prototype.onCreate = function () {
        if (util_1.isFn(this.props.onCreate)) {
            this.props.onCreate();
        }
    };
    /**
     * @stable [23.04.2018]
     * @param {IEntity} entity
     */
    UniversalList.prototype.onSelect = function (entity) {
        var props = this.props;
        if (this.isRowSelectable && util_1.isFn(props.onSelect)) {
            props.onSelect(entity);
        }
    };
    Object.defineProperty(UniversalList.prototype, "isRowSelectable", {
        /**
         * @stable [20.12.2018]
         * @returns {boolean}
         */
        get: function () {
            return this.props.selectable !== false;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [23.04.2018]
     * @param {IEntity} entity
     * @returns {boolean}
     */
    UniversalList.prototype.isEntitySelected = function (entity) {
        var props = this.props;
        return props.selected === entity || (props.selected && props.selected.id === entity.id);
    };
    /**
     * @stable [19.08.2018]
     * @param {IEntity} entity
     * @returns {string}
     */
    UniversalList.prototype.toRowKey = function (entity) {
        return "data-row-" + util_1.ifNilReturnUuid(entity.id, String(entity.id)); // Infinity scroll supporting
    };
    Object.defineProperty(UniversalList.prototype, "originalDataSource", {
        /**
         * @stable [17.06.2018]
         * @returns {IEntity[]}
         */
        get: function () {
            return this.props.data;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "dataSource", {
        /**
         * @stable [17.06.2018]
         * @returns {IEntity[]}
         */
        get: function () {
            var filteredAndSortedEntities = util_1.filterAndSortEntities(this.filterAndSortOriginalDataSourceUsingLocalFiltersAndSorters(), this.props);
            var toNumber = this.toNumber;
            var pagedData;
            return util_1.orDefault(R.isNil(toNumber)
                // Remote and local pagination is supported simultaneously.
                // Length result is zero in the case of remote pagination
                || (pagedData = filteredAndSortedEntities.slice(this.fromNumber, toNumber)).length === 0, filteredAndSortedEntities, function () { return pagedData; });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [09.06.2018]
     * @returns {TMessageComponentProps}
     */
    UniversalList.prototype.getMessageComponentProps = function () {
        var props = this.props;
        return {
            error: props.error,
            progress: props.progress,
            emptyData: this.emptyData,
            emptyMessage: this.emptyMessage,
            emptyDataMessage: props.emptyDataMessage,
            errorMessage: props.error,
        };
    };
    /**
     * @stable [06.06.2018]
     * @returns {IEntity[]}
     */
    UniversalList.prototype.filterAndSortOriginalDataSourceUsingLocalFiltersAndSorters = function () {
        return this.originalDataSource;
    };
    Object.defineProperty(UniversalList.prototype, "isRemoteMode", {
        /**
         * @stable [18.10.2018]
         * @returns {boolean}
         */
        get: function () {
            return !this.props.useLocalFiltering;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "emptyMessage", {
        /**
         * @stable [09.06.2018]
         * @returns {React.ReactNode}
         */
        get: function () {
            return this.props.emptyMessage;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "emptyData", {
        /**
         * @stable [17.06.2018]
         * @returns {boolean}
         */
        get: function () {
            if (this.originalDataSourceDoesNotExist) {
                return false; // It's important to show the difference between the conditions: length === 0 and data === null!
            }
            var dataSource = this.isRemoteMode
                ? this.dataSource
                : this.originalDataSource; // In the case of a local filtering we need to get a false result
            return Array.isArray(dataSource) && dataSource.length === 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "originalDataSourceDoesNotExist", {
        /**
         * @stable [17.06.2018]
         * @returns {boolean}
         */
        get: function () {
            return R.isNil(this.originalDataSource);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "fromNumber", {
        /**
         * @stable [09.05.2018]
         * @returns {number}
         */
        get: function () {
            return util_1.pageFromNumber(this.props) - 1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "toNumber", {
        /**
         * @stable [09.05.2018]
         * @returns {number}
         */
        get: function () {
            return util_1.pageToNumber(this.props);
        },
        enumerable: true,
        configurable: true
    });
    return UniversalList;
}(universal_component_1.UniversalComponent));
exports.UniversalList = UniversalList;
//# sourceMappingURL=universal-list.component.js.map