"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var vue_property_decorator_1 = require("vue-property-decorator");
var R = require("ramda");
var util_1 = require("../../util");
var vue_index_1 = require("../base/vue-index");
var vue_index_2 = require("../popup/vue-index");
var vue_viewer_interface_1 = require("./vue-viewer.interface");
var VueViewer = /** @class */ (function (_super) {
    __extends(VueViewer, _super);
    function VueViewer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @stable [29.11.2018]
     * @param {VueCreateElementFactoryT} createElement
     * @returns {VueNodeT}
     */
    VueViewer.prototype.render = function (createElement) {
        var options = {
            methods: this.getTemplateMethods(),
            template: "\n        <vue-flex-layout class=\"" + this.getClassName() + "\">\n            " + this.getPreviewTemplate() + "\n            " + this.getPreviewTemplateAttachment() + "\n            <vue-popup :open=\"isPopupOpened()\"\n                       className=\"" + this.getPopupClassName() + "\"\n                       @" + vue_index_2.VUE_POPUP_CLOSE_EVENT + "=\"onClosePopup\">\n                <template slot=\"" + vue_index_2.VUE_POPUP_HEADER_SLOT + "\">\n                    " + this.getPopupHeaderTemplate() + "\n                </template>\n                <template>\n                    " + this.getPopupBodyTemplate() + "\n                </template>\n                <template slot=\"" + vue_index_2.VUE_POPUP_FOOTER_SLOT + "\">\n                    " + this.getPopupFooterTemplate() + "\n                </template>\n            </vue-popup>\n        </vue-flex-layout>\n      ",
        };
        return createElement(options);
    };
    /**
     * @stable [29.11.2018]
     * @returns {TVueViewerStateEntity}
     */
    VueViewer.prototype.getInitialData$ = function () {
        return {
            popup: false,
        };
    };
    /**
     * @stable [28.11.2018]
     */
    VueViewer.prototype.onOpenPopup = function () {
        var _this = this;
        this.getData().popup = true;
        this.$nextTick(function () { return _this.onAfterOpenPopup(); });
    };
    /**
     * @stable [29.11.2018]
     * @returns {IVueViewerTemplateMethodsEntity}
     */
    VueViewer.prototype.getTemplateMethods = function () {
        var _this = this;
        return {
            getSrc: function () { return _this.src; },
            isPopupOpened: function () { return _this.getData().popup; },
            onOpenPopup: this.onOpenPopup,
            onClosePopup: this.onClosePopup,
            onRemove: this.onRemove,
        };
    };
    /**
     * @stable [09.12.2018]
     */
    VueViewer.prototype.onRemove = function () {
        this.$emit(vue_viewer_interface_1.VUE_VIEWER_REMOVE_EVENT, this.src);
    };
    /**
     * @stable [29.11.2018]
     * @returns {string}
     */
    VueViewer.prototype.getPopupFooterTemplate = function () {
        return '';
    };
    /**
     * @stable [29.11.2018]
     * @returns {string}
     */
    VueViewer.prototype.getPopupHeaderTemplate = function () {
        return '';
    };
    /**
     * @stable [29.11.2018]
     * @returns {string}
     */
    VueViewer.prototype.getPreviewTemplate = function () {
        return '';
    };
    /**
     * @stable [20.01.2019]
     * @returns {string}
     */
    VueViewer.prototype.getPreviewTemplateAttachment = function () {
        var _this = this;
        return util_1.orEmpty(!R.isNil(this.previewAttachment), function () {
            var content = util_1.calc(_this.previewAttachment, _this.entity);
            return util_1.orEmpty(!R.isNil(content) && !R.isEmpty(content), function () { return ("<div class=\"vue-viewer-preview-attachment\"\n                  v-on:click=\"onOpenPopup\">" + content + "</div>"); });
        });
    };
    /**
     * @stable [22.12.2018]
     * @returns {string}
     */
    VueViewer.prototype.getPreviewClassName = function () {
        return 'vue-viewer-preview';
    };
    /**
     * @stable [06.01.2018]
     * @returns {string}
     */
    VueViewer.prototype.getClassName = function () {
        return util_1.toClassName('vue-viewer', util_1.calc(this.className, this.entity));
    };
    /**
     * @stable [20.01.2019]
     * @returns {string}
     */
    VueViewer.prototype.getPopupClassName = function () {
        return util_1.toClassName('vue-viewer-popup', util_1.calc(this.popupClassName, this.entity));
    };
    /**
     * @stable [28.11.2018]
     * @returns {string}
     */
    VueViewer.prototype.getPopupBodyTemplate = function () {
        return '';
    };
    /**
     * @stable [28.11.2018]
     */
    VueViewer.prototype.onAfterOpenPopup = function () {
        // Do nothing
    };
    /**
     * @stable [28.11.2018]
     */
    VueViewer.prototype.onAfterClosePopup = function () {
        // Do nothing
    };
    /**
     * @stable [28.11.2018]
     */
    VueViewer.prototype.onClosePopup = function () {
        var _this = this;
        this.getData().popup = false;
        this.$nextTick(function () { return _this.onAfterClosePopup(); });
    };
    __decorate([
        vue_property_decorator_1.Prop(),
        __metadata("design:type", String)
    ], VueViewer.prototype, "src", void 0);
    __decorate([
        vue_property_decorator_1.Prop(),
        __metadata("design:type", Object)
    ], VueViewer.prototype, "entity", void 0);
    __decorate([
        vue_property_decorator_1.Prop(),
        __metadata("design:type", Object)
    ], VueViewer.prototype, "previewAttachment", void 0);
    __decorate([
        vue_property_decorator_1.Prop(),
        __metadata("design:type", Object)
    ], VueViewer.prototype, "popupClassName", void 0);
    return VueViewer;
}(vue_index_1.VueBaseComponent));
exports.VueViewer = VueViewer;
//# sourceMappingURL=vue-viewer.component.js.map