"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var env_1 = require("../env");
var util_1 = require("../util");
var StartDayOfWeekT;
(function (StartDayOfWeekT) {
    StartDayOfWeekT[StartDayOfWeekT["MONDAY"] = 0] = "MONDAY";
    StartDayOfWeekT[StartDayOfWeekT["SUNDAY"] = 1] = "SUNDAY";
})(StartDayOfWeekT = exports.StartDayOfWeekT || (exports.StartDayOfWeekT = {}));
exports.REGEXP_REPO = {
    price: '\\d+(\\.\\d{1,2})?',
    number: '[-+]?[0-9]*[.,]?[0-9]+',
    digital: '[0-9]+',
};
exports.DEFAULT_APPLICATION_SETTINGS = {
    usePersistence: true,
    signalRUrl: util_1.prepareUrl(env_1.ENV.basePath + '/api/'),
    downloadUrl: util_1.prepareUrl(env_1.ENV.basePath + '/api/download/?params='),
    emptyPictureUrl: 'media/no_avatar.jpg',
    companyName: 'Test company',
    entityEmptyId: null,
    transport: {
        method: 'post',
        withCredentials: true,
        binaryContentType: 'application/octet-stream',
        formDataContentType: 'multipart/form-data',
        apiUrl: util_1.prepareUrl(env_1.ENV.basePath + '/api/'),
        binaryUrl: util_1.prepareUrl(env_1.ENV.basePath + '/api/blobs/upload/'),
        noCachePrefix: '_dc',
    },
    messages: {
        acceptMessage: 'Accept',
        accessDeniedMessage: 'The access is restricted for you.',
        addressSelectionMessage: 'Address selection',
        applyMessage: 'Apply',
        appNotReadyMessage: 'The application is initialized...',
        clearAllMessage: 'Clear all',
        closeMessage: 'Close',
        confirmationMessage: 'Confirmation',
        continueMessage: 'Continue',
        create: 'Create',
        dataSaved: 'The data has been successfully saved.',
        defaultErrorMessage: 'Error',
        dialogAcceptMessage: 'Continue',
        dialogCancelMessage: 'Cancel',
        dialogTitleMessage: 'Notice',
        dndMessage: 'Upload a file(s) here',
        emptyDataMessage: 'No data found',
        emptyMessage: 'Start a search',
        errorMessage: 'Something went wrong. There was a problem loading your data',
        exportActionTitleMessage: 'Export',
        fileLoadErrorMessage: 'Can\'t load the file.',
        filterPlaceholderMessage: 'Filter',
        filtersMessage: 'Filters',
        followingErrorHasOccurredMessage: 'The following error has occurred:',
        invalidAddressMessage: 'Invalid address',
        logoutNotificationMessage: 'You were logged out.',
        newAppVersionMessageHasBeenDeployed: 'A new app version has been deployed. Need to go to the home page.',
        noAvailableItemsToSelectMessage: 'No available items to select.',
        noFileToShowMessage: 'No file to show.',
        noItemsMessage: 'No items.',
        previewMessage: 'Preview',
        putMarkerHereMessage: 'Put marker here',
        refreshActionTitleMessage: 'Refresh',
        requestCancelErrorMessage: 'The request has been canceled by the user.',
        reset: 'Reset',
        save: 'Save',
        serviceTemporarilyUnavailableMessage: 'Service temporarily unavailable. Please try later.',
        sorryMessage: 'Sorry about that.',
        takeSnapshotMessage: 'Take a snapshot',
        unknownFileMessage: 'Unknown file',
        waitingMessage: 'Waiting...',
        waitMessage: 'Please wait...',
    },
    dateTime: {
        startDayOfWeek: StartDayOfWeekT.MONDAY,
        currentDate: new Date(),
        dateTimeFormat: 'YYYY-MM-DD[T]HH:mm:ssZ',
        dateFormat: 'YYYY-MM-DD',
        timeFormat: 'HH:mm:ss',
        uiDateFormat: 'YYYY-MM-DD',
        uiMonthFormat: 'YYYY-MM',
        uiTimeFormat: 'HH:mm:ss',
        pstTimeFormat: 'hh:mm A',
        pstDateFormat: 'MMM DD',
        uiDateMask: [/\d/, /\d/, /\d/, /\d/, '-', /\d/, /\d/, '-', /\d/, /\d/],
        uiTimeMask: [/\d/, /\d/, ':', /\d/, /\d/, ':', /\d/, /\d/],
        uiShortTimeMask: [/\d/, /\d/, ':', /\d/, /\d/],
        uiDatePattern: '[0-9]{4}-(0[1-9]|1[0-2])-(0[1-9]|[1-2][0-9]|3[0-1])',
        uiTimePattern: '([0-1][0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9])',
        uiShortTimePattern: '([0-1][0-9]|2[0-3]):([0-5][0-9])',
    },
    number: {
        uiPattern: exports.REGEXP_REPO.number,
    },
    phone: {
        uiPattern: '1[0-9]{10}',
        uiMask: [/\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/],
        uiCountryAbbreviation: 'US',
    },
    currency: {
        uiLocale: 'en-US',
        uiCurrency: 'USD',
    },
    channel: {
        eventToListen: 'client-event-to-listen',
        eventToEmit: 'client-event-to-emit',
    },
    authorization: {
        isAuthorizationNeeded: true,
    },
    googleMaps: {
        lat: 34.0522,
        lng: -118.2436,
        zoom: 13,
        prettyZoom: 17,
        libraries: 'places,visualization',
    },
};
//# sourceMappingURL=settings.interface.js.map