import { ITransportResponseFactory, ITransportResponseFactoryResponseEntity } from './transport-response-factory.interface';
import { IDataWrapper, AnyT } from '../../definitions.interface';
import { ITransportRequestEntity } from '../transport.interface';
export declare class TransportResponseFactory implements ITransportResponseFactory {
    /**
     * This is a default error response handler. The core uses Axios by default therefore here we gets a response from this one.
     *
     * @stable [01.02.2019]
     * @param {TransportResponseFactoryPayloadT} payloadEntity
     * @returns {ITransportResponseFactoryResponseEntity}
     */
    makeErrorResponse(payloadEntity: {
        response?: any;
        message?: any;
    }): ITransportResponseFactoryResponseEntity;
    /**
     * This is a default response handler. The core uses Axios by default therefore here we gets a response from this one.
     *
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} req
     * @param {IDataWrapper} payloadEntity
     * @returns {ITransportResponseFactoryResponseEntity}
     */
    makeResponse(req: ITransportRequestEntity, payloadEntity: IDataWrapper<AnyT>): ITransportResponseFactoryResponseEntity;
    /**
     * @stable [02.02.2019]
     * @param {AnyT} data
     * @returns {AnyT}
     */
    protected readResponseData<TData>(data: AnyT): AnyT;
    /**
     * @stable [04.02.2019]
     * @param {AnyT} data
     * @returns {ITransportResponseFactoryResponseEntity}
     */
    protected readErrorResponseData<TData>(data: AnyT): ITransportResponseFactoryResponseEntity;
}
